@@ -4,8 +4,8 @@ from terminusgps.wialon.items.base import WialonBase
 
 class WialonRetranslator(WialonBase):
     def create(self, **kwargs) -> int | None:
-        if not kwargs.get("owner_id"):
-            raise ValueError("'owner_id' is required on creation.")
+        if not kwargs.get("creator_id"):
+            raise ValueError("'creator_id' is required on creation.")
         if not kwargs.get("name"):
             raise ValueError("'name' is required on creation.")
         if not kwargs.get("config"):
@@ -13,7 +13,7 @@ class WialonRetranslator(WialonBase):
 
         response = self.session.wialon_api.core_create_retranslator(
             **{
-                "creatorId": kwargs["owner_id"],
+                "creatorId": kwargs["creator_id"],
                 "name": kwargs["name"],
                 "config": kwargs["config"],
                 "dataFlags": flags.DATAFLAG_UNIT_BASE,
